@@ -7,8 +7,8 @@
 #define BIGSCREENPLUGIN_DBUS_H
 
 #include <QObject>
+#include <QStringList>
 #include <QtDBus>
-#include "bigscreenplugin_dbus.h"
 
 QT_BEGIN_NAMESPACE
 class QByteArray;
@@ -17,7 +17,6 @@ class QList;
 template<class Key, class Value>
 class QMap;
 class QString;
-class QStringList;
 class QVariant;
 QT_END_NAMESPACE
 
